pub struct DynamicHeader {
pub interface: Option<String>,
pub member: Option<String>,
pub object: Option<String>,
pub destination: Option<String>,
pub serial: Option<NonZeroU32>,
pub sender: Option<String>,
pub signature: Option<String>,
pub error_name: Option<String>,
pub response_serial: Option<NonZeroU32>,
pub num_fds: Option<u32>,
}Expand description
The dynamic part of a dbus message header
Fields
interface: Option<String>member: Option<String>object: Option<String>destination: Option<String>serial: Option<NonZeroU32>sender: Option<String>signature: Option<String>error_name: Option<String>response_serial: Option<NonZeroU32>num_fds: Option<u32>Implementations
Sourceimpl DynamicHeader
impl DynamicHeader
Sourcepub fn make_error_response<S: Into<String>>(
&self,
error_name: S,
error_msg: Option<String>,
) -> MarshalledMessage
pub fn make_error_response<S: Into<String>>( &self, error_name: S, error_msg: Option<String>, ) -> MarshalledMessage
Make a correctly addressed error response with the correct response serial
Sourcepub fn make_response(&self) -> MarshalledMessage
pub fn make_response(&self) -> MarshalledMessage
Make a correctly addressed response with the correct response serial
pub fn validate(&self) -> bool